@@ -9,7 +9,7 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-05-22'; # DATE
 our $DIST = 'Array-Shuffle'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 our @EXPORT_OK = qw(shuffle);
 
@@ -46,7 +46,7 @@ Array::Shuffle - Shuffle an array
 
 =head1 VERSION
 
-This document describes version 0.001 of Array::Shuffle (from Perl distribution Array-Shuffle), released on 2022-05-22.
+This document describes version 0.002 of Array::Shuffle (from Perl distribution Array-Shuffle), released on 2022-05-22.
 
 =head1 SYNOPSIS
 
@@ -88,6 +88,11 @@ The Fisher-Yates shuffle algorithm described by Durstenfeld, 1964.
 L<Algorithm::Numerical::Shuffle> and a few others like L<List::MoreUtils::PP>'s
 C<samples> do the same thing.
 
+Modules that provide a random-sampling-without-replacement function can also be
+used to shuffle. Shuffling is basically random total sampling. These modules
+include L<List::Util> (C<sample>), L<List::MoreUtils> (L<samples>),
+L<Array::Sample::SimpleRandom>.
+
 L<Array::Shuffle::Weighted>
 
 =head1 AUTHOR
